@@ -7,4 +7,6 @@ from meaningcloud.ClassResponse import *
 from meaningcloud.SentimentRequest import *
 from meaningcloud.SentimentResponse import *
 from meaningcloud.LanguageRequest import *
-from meaningcloud.LanguageResponse import *
\ No newline at end of file
+from meaningcloud.LanguageResponse import *
+from meaningcloud.ParserRequest import *
+from meaningcloud.ParserResponse import *
